# FACT Electric Power Generation and Transmission

Location, size, and type of electricity generation plants and transmission lines, in Europe and US.

---

[![GitLab License](https://img.shields.io/gitlab/license/fact%2Fdata%2FFACT_power?gitlab_url=https%3A%2F%2Fgit.nilu.no&style=flat&color=orange)](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html)
[![DOI](https://img.shields.io/badge/DOI-10.17605%2FOSF.IO%2F6TD3S-blue?style=flat)](https://doi.org/10.17605/OSF.IO/6TD3S)
[![Data License](https://img.shields.io/badge/data-CC%20BY%204.0-green)](https://creativecommons.org/licenses/by/4.0/legalcode.txt)


---


## Use
1. Through the command line:
```bash
docker pull registry.git.nilu.no/fact/data/fact_power:latest
docker run -t -i --name fact_power -e MARIADB_DATABASE=FACT_power -e MYSQL_ROOT_PASSWORD=devops -p 3313:3306 -d registry.git.nilu.no/fact/data/fact_power:latest
```
2. Through a docker-compose file:
```yaml
version: '3.8'

services:
  fact_power:
    image: registry.git.nilu.no/fact/data/fact_power:latest
    container_name: fact_power
    environment:
      MARIADB_DATABASE: FACT_power
      MYSQL_ROOT_PASSWORD: devops
    ports:
      - "3313:3306"
    restart: unless-stopped
```
which could be executed with `docker-compose up fact_power -d`.

The container makes available a MariaDB instance with the full database on population **FACT_power**. It is reachable on port 3313 of the localhost and the root password is 'devops'.

---
## Specifications
```
Table           |Size (MB)|Rows (#)|
----------------+---------+--------+
eu_gen          |     1.18|    4891|
eu_trans        |     1.98|    9007|
geometry_columns|     0.02|       4|
spatial_ref_sys |     0.02|       0|
us_gen          |     4.44|   12008|
us_trans        |    79.84|   94216|
```
![tables schema](FACT_power.png "Tables in DB")

**All spatial objects are converted to EPSG:4326.**

---
## Notes
Europe data:
- Power Plants: EU OPEN database of power plants, 2017, https://visitors-centre.jrc.ec.europa.eu/tools/powerplants/ with data published at [doi: 10.5281/zenodo.3574566](https://doi.org/10.5281/zenodo.3574566)
- Power Transmission Lines: ENTSO-E Transmission System [Map](https://www.entsoe.eu/data/map/) 

US data:
- Power Plants: EIA, US Energy Atlas, [Power Plants](https://atlas-eia.opendata.arcgis.com/datasets/bf5c5110b1b944d299bb683cdbd02d2a/explore)
- Power Transmission Lines: EIA, US Energy Atlas, [Transmission Lines](https://atlas.eia.gov/datasets/bd24d1a282c54428b024988d32578e59_0/explore?location=39.579031%2C57.733818%2C4.25)

---
## Author
Riccardo Boero - ribo@nilu.no

## Licenses
All the code and the resulting docker images in this project are subject to:
- [GNU General Public License v2](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).


The data is released under: 
- [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/) license.

The input data is licensed as:
- EU power palants follows [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/) license.
- ENTSOE data [terms of use](https://transparency.entsoe.eu/content/static_content/download?path=/Static%20content/terms%20and%20conditions/181108_ENTSOE_Transparency_Terms_Conditions_MC_APPROVED.pdf&loggedUserIsPrivileged=false).
- EIA public domain [data copyrights](https://www.eia.gov/about/copyrights_reuse.php).

## Citation
- Boero, Riccardo. 2024. “FACT Data: Electric Power Generation and Transmission.” OSF. [doi:10.17605/OSF.IO/6TD3S](https://doi.org/10.17605/OSF.IO/6TD3S). 

Part of the Fine scAle eConomic daTa - FACT project:
- Boero, Riccardo. 2024. “Fine scAle eConomic daTa - FACT.” OSF. [doi:10.17605/OSF.IO/PV4ZW](https://doi.org/10.17605/OSF.IO/PV4ZW). 

